package com.usky.dxtop.controller.web;


import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.usky.dxtop.common.annotation.RepeatSubmit;
import com.usky.dxtop.common.core.domain.AjaxResult;
import com.usky.dxtop.common.utils.DateUtils;
import com.usky.dxtop.controller.BaseController;
import com.usky.dxtop.model.Order;
import com.usky.dxtop.service.OrderService;
import com.usky.dxtop.service.emun.OrderStatus;
import com.usky.dxtop.service.vo.OrderRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.Date;

/**
 * <p>
 * 订单表 前端控制器
 * </p>
 *
 * @author yq
 * @since 2021-08-26
 */
@RestController
@RequestMapping("/dxtop/order")
public class OrderController extends BaseController {

    @Autowired
    private OrderService orderService;

    /**
     * 添加订单(现金支付)
     * @param order
     * @return
     */
    @RepeatSubmit
    @PostMapping
    public AjaxResult add(@RequestBody Order order){
        return toAjax(orderService.add(order));
    }

    /**
     * 修改订单状态
     * @param order
     * @return
     */
    @PutMapping
    public AjaxResult update(@RequestBody Order order){
        order.setOrderFlag(OrderStatus.COMPLETE.getCode());
        return toAjax(orderService.updateById(order));
    }

    /**
     * 删除订单
     * @param orderNumber
     * @return
     */
    @DeleteMapping("/{orderNumber}")
    public AjaxResult remove(@PathVariable("orderNumber") String orderNumber){
        return toAjax(orderService.remove(orderNumber));
    }

    /**
     * 分页
     * @param orderRequest
     * @return
     */
    @PostMapping("/list")
    public AjaxResult list(@RequestBody OrderRequest orderRequest){
        return AjaxResult.success(orderService.list(orderRequest));
    }

    /**
     * 扫码支付api
     * @param order
     * @return
     */
    @RepeatSubmit
    @PostMapping("/topScanPayApi")
    public AjaxResult getTopScanPayApi(@RequestBody Order order){
        return AjaxResult.success(orderService.getTopScanPayApi(order));
    }

    /**
     * 查看订单详情api
     * @param orderNumber
     * @return
     */
    @GetMapping("/{orderNumber}")
    public AjaxResult callTopFindOrderInfoApi(@PathVariable("orderNumber") String orderNumber){
        return AjaxResult.success(orderService.callTopFindOrderInfoApi(orderNumber));
    }

    @PostMapping("/exportDetail")
    public AjaxResult exportDetail(@RequestBody OrderRequest orderRequest){
        return AjaxResult.success(orderService.exportDetail(orderRequest));
    }

    /**
     * 订单报表
     * @param current
     * @param size
     * @param startTime
     * @param endTime
     * @param type
     * @return
     */
    @GetMapping("/orderReportList")
    public AjaxResult orderReportList(@RequestParam Integer current,
                                      @RequestParam Integer size,
                                      @RequestParam(required = false) Date startTime,
                                      @RequestParam(required = false) Date endTime,
                                      @RequestParam Integer type){
        return AjaxResult.success(orderService.orderReportList(current,size,startTime,endTime,type));
    }

    /**
     * 报表导出
     * @param startTime
     * @param endTime
     * @param type
     * @return
     */
    @GetMapping("/reportExport")
    public AjaxResult reportExport(@RequestParam(required = false) Date startTime,
                           @RequestParam(required = false) Date endTime,
                           @RequestParam Integer type){
        return AjaxResult.success(orderService.reportExport(startTime, endTime, type));
    }

    /**
     * 统一支付
     * @param order
     * @return
     */
    @RepeatSubmit
    @PostMapping("/callUnifiedPay")
    public AjaxResult callUnifiedPay(@RequestBody Order order){
        return AjaxResult.success(orderService.callUnifiedPay(order));
    }

    /**
     * 支付方式汇总
     * @return
     */
    @GetMapping("/payTypeCollect")
    public AjaxResult payTypeCollect(){
        return AjaxResult.success(orderService.payTypeCollect());
    }

    /**
     * 充值金额/充值次数
     * @return
     */
    @GetMapping("/orderMoney")
    public AjaxResult orderMoney(){
        Date date = new Date();
        QueryWrapper<Order> queryWrapper = new QueryWrapper<>();
        queryWrapper.select("IFNULL(sum(money),0) as total","count(*) as count")
                .and(wrapper -> wrapper.eq("order_flag",OrderStatus.SUCCESS.getCode()).or().eq("order_flag",OrderStatus.COMPLETE.getCode()))
                .between("create_time",DateUtils.getDayStartTime(date),date);
        return AjaxResult.success(orderService.getMap(queryWrapper));
    }

    /**
     * 日期汇总
     * @param type
     * @return
     */
    @GetMapping("/dateCollect")
    public AjaxResult dateCollect(@RequestParam Integer type,
                                  @RequestParam Date startTime,
                                  @RequestParam Date endTime){
        return AjaxResult.success(orderService.dateCollect(type,startTime,endTime));
    }

}

